@@ -1,10 +1,7 @@
-# -*- coding: utf-8 -*-
 """
 Salt package
 """
 
-from __future__ import absolute_import, print_function, unicode_literals
-
 import importlib
 import sys
 import warnings
@@ -16,20 +13,43 @@ if sys.version_info < (3,):
     sys.stderr.flush()
 
 
-class TornadoImporter(object):
+USE_VENDORED_TORNADO = True
+
+
+class TornadoImporter:
     def find_module(self, module_name, package_path=None):
-        if module_name.startswith("tornado"):
+        if USE_VENDORED_TORNADO:
+            if module_name.startswith("tornado"):
+                return self
+        else:
+            if module_name.startswith("salt.ext.tornado"):
+                return self
+        return None
+
+    def load_module(self, name):
+        if USE_VENDORED_TORNADO:
+            mod = importlib.import_module("salt.ext.{}".format(name))
+        else:
+            # Remove 'salt.ext.' from the module
+            mod = importlib.import_module(name[9:])
+        sys.modules[name] = mod
+        return mod
+
+
+class SixRedirectImporter:
+    def find_module(self, module_name, package_path=None):
+        if module_name.startswith("salt.ext.six"):
             return self
         return None
 
     def load_module(self, name):
-        mod = importlib.import_module("salt.ext.{}".format(name))
+        mod = importlib.import_module(name[9:])
         sys.modules[name] = mod
         return mod
 
 
 # Try our importer first
-sys.meta_path = [TornadoImporter()] + sys.meta_path
+sys.meta_path = [TornadoImporter(), SixRedirectImporter()] + sys.meta_path
 
 
 # All salt related deprecation warnings should be shown once each!
@@ -41,14 +61,6 @@ warnings.filterwarnings(
     append=True,
 )
 
-# While we are supporting Python2.6, hide nested with-statements warnings
-warnings.filterwarnings(
-    "ignore",
-    "With-statements now directly support multiple context managers",
-    DeprecationWarning,
-    append=True,
-)
-
 # Filter the backports package UserWarning about being re-imported
 warnings.filterwarnings(
     "ignore",
@@ -104,13 +116,7 @@ def __define_global_system_encoding_variable__():
                 # On linux default to ascii as a last resort
                 encoding = "ascii"
 
-    # We can't use six.moves.builtins because these builtins get deleted sooner
-    # than expected. See:
-    #    https://github.com/saltstack/salt/issues/21036
-    if sys.version_info[0] < 3:
-        import __builtin__ as builtins  # pylint: disable=incompatible-py3-code
-    else:
-        import builtins  # pylint: disable=import-error
+    import builtins
 
     # Define the detected encoding as a built-in variable for ease of use
     setattr(builtins, "__salt_system_encoding__", encoding)
@@ -125,3 +131,10 @@ __define_global_system_encoding_variable__()
 
 # This is now garbage collectable
 del __define_global_system_encoding_variable__
+
+# Make sure Salt's logging tweaks are always present
+# DO NOT MOVE THIS IMPORT
+# pylint: disable=unused-import
+import salt._logging  # isort:skip
+
+# pylint: enable=unused-import
