@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-'''
+"""
 IPS pkg support for Solaris
 
 .. important::
@@ -34,83 +33,80 @@ Or you can override it globally by setting the :conf_minion:`providers` paramete
     providers:
       pkg: pkgutil
 
-'''
-# Import python libs
-from __future__ import absolute_import, print_function, unicode_literals
+"""
+
 import copy
 import logging
-import itertools
 
-
-# Import salt libs
 import salt.utils.data
 import salt.utils.functools
 import salt.utils.path
 import salt.utils.pkg
-from salt.ext.six import string_types
 from salt.exceptions import CommandExecutionError
-from salt.ext import six
-from salt.ext.six.moves import zip  # pylint: disable=redefined-builtin
-from functools import reduce
 
 # Define the module's virtual name
-__virtualname__ = 'pkg'
+__virtualname__ = "pkg"
 log = logging.getLogger(__name__)
 
 
 def __virtual__():
-    '''
+    """
     Set the virtual pkg module if the os is Solaris 11
-    '''
-    if __grains__['os_family'] == 'Solaris' \
-            and float(__grains__['kernelrelease']) > 5.10 \
-            and salt.utils.path.which('pkg'):
+    """
+    if (
+        __grains__["os_family"] == "Solaris"
+        and float(__grains__["kernelrelease"]) > 5.10
+        and salt.utils.path.which("pkg")
+    ):
         return __virtualname__
-    return (False,
-            'The solarisips execution module failed to load: only available '
-            'on Solaris >= 11.')
+    return (
+        False,
+        "The solarisips execution module failed to load: only available "
+        "on Solaris >= 11.",
+    )
 
 
 ips_pkg_return_values = {
-    0: 'Command succeeded.',
-    1: 'An error occurred.',
-    2: 'Invalid command line options were specified.',
-    3: 'Multiple operations were requested, but only some of them succeeded.',
-    4: 'No changes were made - nothing to do.',
-    5: 'The requested operation cannot be performed on a  live image.',
-    6: 'The requested operation cannot be completed because the licenses for '
-       'the packages being installed or updated have not been accepted.',
-    7: 'The image is currently in use by another process and cannot be '
-       'modified.'
+    0: "Command succeeded.",
+    1: "An error occurred.",
+    2: "Invalid command line options were specified.",
+    3: "Multiple operations were requested, but only some of them succeeded.",
+    4: "No changes were made - nothing to do.",
+    5: "The requested operation cannot be performed on a  live image.",
+    6: (
+        "The requested operation cannot be completed because the licenses for "
+        "the packages being installed or updated have not been accepted."
+    ),
+    7: "The image is currently in use by another process and cannot be modified.",
 }
 
 
 def _ips_get_pkgname(line):
-    '''
+    """
     Extracts package name from "pkg list -v" output.
     Input: one line of the command output
     Output: pkg name (e.g.: "pkg://solaris/x11/library/toolkit/libxt")
     Example use:
     line = "pkg://solaris/x11/library/toolkit/libxt@1.1.3,5.11-0.175.1.0.0.24.1317:20120904T180030Z i--"
     name = _ips_get_pkgname(line)
-    '''
-    return line.split()[0].split('@')[0].strip()
+    """
+    return line.split()[0].split("@")[0].strip()
 
 
 def _ips_get_pkgversion(line):
-    '''
+    """
     Extracts package version from "pkg list -v" output.
     Input: one line of the command output
     Output: package version (e.g.: "1.1.3,5.11-0.175.1.0.0.24.1317:20120904T180030Z")
     Example use:
     line = "pkg://solaris/x11/library/toolkit/libxt@1.1.3,5.11-0.175.1.0.0.24.1317:20120904T180030Z i--"
     name = _ips_get_pkgversion(line)
-    '''
-    return line.split()[0].split('@')[1].strip()
+    """
+    return line.split()[0].split("@")[1].strip()
 
 
-def refresh_db(full=False):
-    '''
+def refresh_db(full=False, **kwargs):
+    """
     Updates the remote repos database.
 
     full : False
@@ -124,17 +120,17 @@ def refresh_db(full=False):
 
         salt '*' pkg.refresh_db
         salt '*' pkg.refresh_db full=True
-    '''
+    """
     # Remove rtag file to keep multiple refreshes from happening in pkg states
     salt.utils.pkg.clear_rtag(__opts__)
     if full:
-        return __salt__['cmd.retcode']('/bin/pkg refresh --full') == 0
+        return __salt__["cmd.retcode"]("/bin/pkg refresh --full") == 0
     else:
-        return __salt__['cmd.retcode']('/bin/pkg refresh') == 0
+        return __salt__["cmd.retcode"]("/bin/pkg refresh") == 0
 
 
-def upgrade_available(name):
-    '''
+def upgrade_available(name, **kwargs):
+    """
     Check if there is an upgrade available for a certain package
     Accepts full or partial FMRI. Returns all matches found.
 
@@ -143,10 +139,10 @@ def upgrade_available(name):
     .. code-block:: bash
 
         salt '*' pkg.upgrade_available apache-22
-    '''
+    """
     version = None
-    cmd = ['pkg', 'list', '-Huv', name]
-    lines = __salt__['cmd.run_stdout'](cmd).splitlines()
+    cmd = ["pkg", "list", "-Huv", name]
+    lines = __salt__["cmd.run_stdout"](cmd).splitlines()
     if not lines:
         return {}
     ret = {}
@@ -156,7 +152,7 @@ def upgrade_available(name):
 
 
 def list_upgrades(refresh=True, **kwargs):  # pylint: disable=W0613
-    '''
+    """
     Lists all packages available for update.
 
     When run in global zone, it reports only upgradable packages for the global
@@ -185,19 +181,19 @@ def list_upgrades(refresh=True, **kwargs):  # pylint: disable=W0613
 
         salt '*' pkg.list_upgrades
         salt '*' pkg.list_upgrades refresh=False
-    '''
+    """
     if salt.utils.data.is_true(refresh):
         refresh_db(full=True)
     upgrades = {}
     # awk is in core-os package so we can use it without checking
-    lines = __salt__['cmd.run_stdout']("/bin/pkg list -Huv").splitlines()
+    lines = __salt__["cmd.run_stdout"]("/bin/pkg list -Huv").splitlines()
     for line in lines:
         upgrades[_ips_get_pkgname(line)] = _ips_get_pkgversion(line)
     return upgrades
 
 
 def upgrade(refresh=False, **kwargs):
-    '''
+    """
     Upgrade all packages to the latest possible version.
     When run in global zone, it updates also all non-global zones.
     In non-global zones upgrade is limited by dependency constrains linked to
@@ -213,13 +209,12 @@ def upgrade(refresh=False, **kwargs):
     When there is a failure, an explanation is also included in the error
     message, based on the return code of the ``pkg update`` command.
 
-
     CLI Example:
 
     .. code-block:: bash
 
         salt '*' pkg.upgrade
-    '''
+    """
     if salt.utils.data.is_true(refresh):
         refresh_db()
 
@@ -229,27 +224,39 @@ def upgrade(refresh=False, **kwargs):
 
     # Install or upgrade the package
     # If package is already installed
-    cmd = ['pkg', 'update', '-v', '--accept']
-    result = __salt__['cmd.run_all'](cmd,
-                                     output_loglevel='trace',
-                                     python_shell=False)
-    __context__.pop('pkg.list_pkgs', None)
+    cmd = ["pkg", "update", "-v", "--accept"]
+    result = __salt__["cmd.run_all"](cmd, output_loglevel="trace", python_shell=False)
+    __context__.pop("pkg.list_pkgs", None)
     new = list_pkgs()
     ret = salt.utils.data.compare_dicts(old, new)
 
-    if result['retcode'] != 0:
+    if result["retcode"] != 0:
         raise CommandExecutionError(
-            'Problem encountered upgrading packages',
-            info={'changes': ret,
-                  'retcode': ips_pkg_return_values[result['retcode']],
-                  'result': result}
+            "Problem encountered upgrading packages",
+            info={
+                "changes": ret,
+                "retcode": ips_pkg_return_values[result["retcode"]],
+                "result": result,
+            },
         )
 
     return ret
 
 
+def _list_pkgs_from_context(versions_as_list):
+    """
+    Use pkg list from __context__
+    """
+    if versions_as_list:
+        return __context__["pkg.list_pkgs"]
+    else:
+        ret = copy.deepcopy(__context__["pkg.list_pkgs"])
+        __salt__["pkg_resource.stringify"](ret)
+        return ret
+
+
 def list_pkgs(versions_as_list=False, **kwargs):
-    '''
+    """
     List the currently installed packages as a dict::
 
         {'<package_name>': '<version>'}
@@ -259,38 +266,34 @@ def list_pkgs(versions_as_list=False, **kwargs):
     .. code-block:: bash
 
         salt '*' pkg.list_pkgs
-    '''
+    """
     # not yet implemented or not applicable
-    if any([salt.utils.data.is_true(kwargs.get(x))
-        for x in ('removed', 'purge_desired')]):
+    if any(
+        [salt.utils.data.is_true(kwargs.get(x)) for x in ("removed", "purge_desired")]
+    ):
         return {}
 
-    if 'pkg.list_pkgs' in __context__:
-        if versions_as_list:
-            return __context__['pkg.list_pkgs']
-        else:
-            ret = copy.deepcopy(__context__['pkg.list_pkgs'])
-            __salt__['pkg_resource.stringify'](ret)
-            return ret
+    if "pkg.list_pkgs" in __context__ and kwargs.get("use_context", True):
+        return _list_pkgs_from_context(versions_as_list)
 
     ret = {}
-    cmd = '/bin/pkg list -Hv'
-    lines = __salt__['cmd.run_stdout'](cmd).splitlines()
+    cmd = "/bin/pkg list -Hv"
+    lines = __salt__["cmd.run_stdout"](cmd).splitlines()
     # column 1 is full FMRI name in form pkg://publisher/class/name@version
     for line in lines:
         name = _ips_get_pkgname(line)
         version = _ips_get_pkgversion(line)
-        __salt__['pkg_resource.add_pkg'](ret, name, version)
+        __salt__["pkg_resource.add_pkg"](ret, name, version)
 
-    __salt__['pkg_resource.sort_pkglist'](ret)
-    __context__['pkg.list_pkgs'] = copy.deepcopy(ret)
+    __salt__["pkg_resource.sort_pkglist"](ret)
+    __context__["pkg.list_pkgs"] = copy.deepcopy(ret)
     if not versions_as_list:
-        __salt__['pkg_resource.stringify'](ret)
+        __salt__["pkg_resource.stringify"](ret)
     return ret
 
 
 def version(*names, **kwargs):
-    '''
+    """
     Common interface for obtaining the version of installed packages.
     Accepts full or partial FMRI. If called using pkg_resource, full FMRI is required.
     Partial FMRI is returned if the package is not installed.
@@ -303,33 +306,34 @@ def version(*names, **kwargs):
         salt '*' pkg.version foo bar baz
         salt '*' pkg_resource.version pkg://solaris/entire
 
-    '''
+    """
     if len(names) == 0:
-        return ''
+        return ""
 
-    cmd = ['/bin/pkg', 'list', '-Hv']
+    cmd = ["/bin/pkg", "list", "-Hv"]
     cmd.extend(names)
-    lines = __salt__['cmd.run_stdout'](cmd, ignore_retcode=True).splitlines()
+    lines = __salt__["cmd.run_stdout"](cmd, ignore_retcode=True).splitlines()
     ret = {}
     for line in lines:
         ret[_ips_get_pkgname(line)] = _ips_get_pkgversion(line)
 
     # Append package names which are not installed/found
-    unmatched = list([name for name in names if not reduce(lambda x, y: x or name in y, ret, False)])  # pylint: disable=W0640
-    ret.update(zip(unmatched, itertools.cycle(('',))))
+    for name in names:
+        if name not in ret:
+            ret[name] = ""
 
     # Return a string if only one package name passed
     if len(names) == 1:
         try:
-            return next(six.itervalues(ret))
+            return next(iter(ret.values()))
         except StopIteration:
-            return ''
+            return ""
 
     return ret
 
 
 def latest_version(*names, **kwargs):
-    '''
+    """
     The available version of packages in the repository.
     Accepts full or partial FMRI. Partial FMRI is returned if the full FMRI
     could not be resolved.
@@ -349,14 +353,14 @@ def latest_version(*names, **kwargs):
         salt '*' pkg.latest_version bash
         salt '*' pkg.latest_version pkg://solaris/entire
         salt '*' pkg.latest_version postfix sendmail
-    '''
+    """
 
     if len(names) == 0:
-        return ''
+        return ""
 
-    cmd = ['/bin/pkg', 'list', '-Hnv']
+    cmd = ["/bin/pkg", "list", "-Hnv"]
     cmd.extend(names)
-    lines = __salt__['cmd.run_stdout'](cmd, ignore_retcode=True).splitlines()
+    lines = __salt__["cmd.run_stdout"](cmd, ignore_retcode=True).splitlines()
     ret = {}
     for line in lines:
         ret[_ips_get_pkgname(line)] = _ips_get_pkgversion(line)
@@ -371,28 +375,31 @@ def latest_version(*names, **kwargs):
         if name not in installed:
             continue
         if ret[name] == installed[name]:
-            ret[name] = ''
+            ret[name] = ""
 
     # Append package names which are not found
-    unmatched = list([name for name in names if not reduce(lambda x, y: x or name in y, ret, False)])
-    ret.update(zip(unmatched, itertools.cycle(('',))))
+    for name in names:
+        if name not in ret:
+            ret[name] = ""
 
     # Return a string if only one package name passed
     if len(names) == 1:
         try:
-            return next(six.itervalues(ret))
+            return next(iter(ret.values()))
         except StopIteration:
-            return ''
+            return ""
 
     return ret
 
 
 # available_version is being deprecated
-available_version = salt.utils.functools.alias_function(latest_version, 'available_version')
+available_version = salt.utils.functools.alias_function(
+    latest_version, "available_version"
+)
 
 
 def get_fmri(name, **kwargs):
-    '''
+    """
     Returns FMRI from partial name. Returns empty string ('') if not found.
     In case of multiple match, the function returns list of all matched packages.
 
@@ -401,16 +408,16 @@ def get_fmri(name, **kwargs):
     .. code-block:: bash
 
         salt '*' pkg.get_fmri bash
-    '''
-    if name.startswith('pkg://'):
+    """
+    if name.startswith("pkg://"):
         # already full fmri
         return name
-    cmd = ['/bin/pkg', 'list', '-aHv', name]
+    cmd = ["/bin/pkg", "list", "-aHv", name]
     # there can be more packages matching the name
-    lines = __salt__['cmd.run_stdout'](cmd).splitlines()
+    lines = __salt__["cmd.run_stdout"](cmd).splitlines()
     if not lines:
         # empty string = package not found
-        return ''
+        return ""
     ret = []
     for line in lines:
         ret.append(_ips_get_pkgname(line))
@@ -419,7 +426,7 @@ def get_fmri(name, **kwargs):
 
 
 def normalize_name(name, **kwargs):
-    '''
+    """
     Internal function. Normalizes pkg name to full FMRI before running
     pkg.install. In case of multiple matches or no match, it returns the name
     without modifications.
@@ -429,13 +436,13 @@ def normalize_name(name, **kwargs):
     .. code-block:: bash
 
         salt '*' pkg.normalize_name vim
-    '''
-    if name.startswith('pkg://'):
+    """
+    if name.startswith("pkg://"):
         # already full fmri
         return name
-    cmd = ['/bin/pkg', 'list', '-aHv', name]
+    cmd = ["/bin/pkg", "list", "-aHv", name]
     # there can be more packages matching the name
-    lines = __salt__['cmd.run_stdout'](cmd).splitlines()
+    lines = __salt__["cmd.run_stdout"](cmd).splitlines()
     # if we get more lines, it's multiple match (name not unique)
     # if we get zero lines, pkg is not installed
     # in both ways it's safer to return original (unmodified) name and let "pkg install" to deal with it
@@ -446,7 +453,7 @@ def normalize_name(name, **kwargs):
 
 
 def is_installed(name, **kwargs):
-    '''
+    """
     Returns True if the package is installed. Otherwise returns False.
     Name can be full or partial FMRI.
     In case of multiple match from partial FMRI name, it returns True.
@@ -456,14 +463,14 @@ def is_installed(name, **kwargs):
     .. code-block:: bash
 
         salt '*' pkg.is_installed bash
-    '''
+    """
 
-    cmd = ['/bin/pkg', 'list', '-Hv', name]
-    return __salt__['cmd.retcode'](cmd) == 0
+    cmd = ["/bin/pkg", "list", "-Hv", name]
+    return __salt__["cmd.retcode"](cmd) == 0
 
 
 def search(name, versions_as_list=False, **kwargs):
-    '''
+    """
     Searches the repository for given pkg name.
     The name can be full or partial FMRI. All matches are printed. Globs are
     also supported.
@@ -473,28 +480,28 @@ def search(name, versions_as_list=False, **kwargs):
     .. code-block:: bash
 
         salt '*' pkg.search bash
-    '''
+    """
 
     ret = {}
-    cmd = ['/bin/pkg', 'list', '-aHv', name]
-    out = __salt__['cmd.run_all'](cmd, ignore_retcode=True)
-    if out['retcode'] != 0:
+    cmd = ["/bin/pkg", "list", "-aHv", name]
+    out = __salt__["cmd.run_all"](cmd, ignore_retcode=True)
+    if out["retcode"] != 0:
         # error = nothing found
         return {}
     # no error, processing pkg listing
     # column 1 is full FMRI name in form pkg://publisher/pkg/name@version
-    for line in out['stdout'].splitlines():
+    for line in out["stdout"].splitlines():
         name = _ips_get_pkgname(line)
         version = _ips_get_pkgversion(line)
-        __salt__['pkg_resource.add_pkg'](ret, name, version)
+        __salt__["pkg_resource.add_pkg"](ret, name, version)
 
     if not versions_as_list:
-        __salt__['pkg_resource.stringify'](ret)
+        __salt__["pkg_resource.stringify"](ret)
     return ret
 
 
 def install(name=None, refresh=False, pkgs=None, version=None, test=False, **kwargs):
-    '''
+    """
     Install the named package using the IPS pkg command.
     Accepts full or partial FMRI.
 
@@ -509,7 +516,6 @@ def install(name=None, refresh=False, pkgs=None, version=None, test=False, **kwa
     pkgs
         A list of packages to install. Must be passed as a python list.
 
-
     CLI Example:
 
     .. code-block:: bash
@@ -518,7 +524,7 @@ def install(name=None, refresh=False, pkgs=None, version=None, test=False, **kwa
         salt '*' pkg.install pkg://solaris/editor/vim
         salt '*' pkg.install pkg://solaris/editor/vim refresh=True
         salt '*' pkg.install pkgs='["foo", "bar"]'
-    '''
+    """
     if not pkgs:
         if is_installed(name):
             return {}
@@ -526,30 +532,30 @@ def install(name=None, refresh=False, pkgs=None, version=None, test=False, **kwa
     if refresh:
         refresh_db(full=True)
 
-    pkg2inst = ''
-    if pkgs:    # multiple packages specified
+    pkg2inst = ""
+    if pkgs:  # multiple packages specified
         pkg2inst = []
         for pkg in pkgs:
-            if getattr(pkg, 'items', False):
-                if list(pkg.items())[0][1]:   # version specified
-                    pkg2inst.append('{0}@{1}'.format(list(pkg.items())[0][0],
-                                                     list(pkg.items())[0][1]))
+            if getattr(pkg, "items", False):
+                if list(pkg.items())[0][1]:  # version specified
+                    pkg2inst.append(
+                        "{}@{}".format(list(pkg.items())[0][0], list(pkg.items())[0][1])
+                    )
                 else:
                     pkg2inst.append(list(pkg.items())[0][0])
             else:
-                pkg2inst.append("{0}".format(pkg))
-        log.debug('Installing these packages instead of %s: %s',
-                  name, pkg2inst)
+                pkg2inst.append("{}".format(pkg))
+        log.debug("Installing these packages instead of %s: %s", name, pkg2inst)
 
-    else:   # install single package
+    else:  # install single package
         if version:
-            pkg2inst = "{0}@{1}".format(name, version)
+            pkg2inst = "{}@{}".format(name, version)
         else:
-            pkg2inst = "{0}".format(name)
+            pkg2inst = "{}".format(name)
 
-    cmd = ['pkg', 'install', '-v', '--accept']
+    cmd = ["pkg", "install", "-v", "--accept"]
     if test:
-        cmd.append('-n')
+        cmd.append("-n")
 
     # Get a list of the packages before install so we can diff after to see
     # what got installed.
@@ -557,37 +563,37 @@ def install(name=None, refresh=False, pkgs=None, version=None, test=False, **kwa
 
     # Install or upgrade the package
     # If package is already installed
-    if isinstance(pkg2inst, string_types):
+    if isinstance(pkg2inst, str):
         cmd.append(pkg2inst)
     elif isinstance(pkg2inst, list):
         cmd = cmd + pkg2inst
 
-    out = __salt__['cmd.run_all'](cmd, output_loglevel='trace')
+    out = __salt__["cmd.run_all"](cmd, output_loglevel="trace")
 
     # Get a list of the packages again, including newly installed ones.
-    __context__.pop('pkg.list_pkgs', None)
+    __context__.pop("pkg.list_pkgs", None)
     new = list_pkgs()
     ret = salt.utils.data.compare_dicts(old, new)
 
-    if out['retcode'] != 0:
+    if out["retcode"] != 0:
         raise CommandExecutionError(
-            'Error occurred installing package(s)',
+            "Error occurred installing package(s)",
             info={
-                'changes': ret,
-                'retcode': ips_pkg_return_values[out['retcode']],
-                'errors': [out['stderr']]
-            }
+                "changes": ret,
+                "retcode": ips_pkg_return_values[out["retcode"]],
+                "errors": [out["stderr"]],
+            },
         )
 
     # No error occurred
     if test:
-        return 'Test succeeded.'
+        return "Test succeeded."
 
     return ret
 
 
 def remove(name=None, pkgs=None, **kwargs):
-    '''
+    """
     Remove specified package. Accepts full or partial FMRI.
     In case of multiple match, the command fails and won't modify the OS.
 
@@ -612,41 +618,41 @@ def remove(name=None, pkgs=None, **kwargs):
         salt '*' pkg.remove tcsh
         salt '*' pkg.remove pkg://solaris/shell/tcsh
         salt '*' pkg.remove pkgs='["foo", "bar"]'
-    '''
+    """
     targets = salt.utils.args.split_input(pkgs) if pkgs else [name]
     if not targets:
         return {}
 
     if pkgs:
-        log.debug('Removing these packages instead of %s: %s', name, targets)
+        log.debug("Removing these packages instead of %s: %s", name, targets)
 
     # Get a list of the currently installed pkgs.
     old = list_pkgs()
 
     # Remove the package(s)
-    cmd = ['/bin/pkg', 'uninstall', '-v'] + targets
-    out = __salt__['cmd.run_all'](cmd, output_loglevel='trace')
+    cmd = ["/bin/pkg", "uninstall", "-v"] + targets
+    out = __salt__["cmd.run_all"](cmd, output_loglevel="trace")
 
     # Get a list of the packages after the uninstall
-    __context__.pop('pkg.list_pkgs', None)
+    __context__.pop("pkg.list_pkgs", None)
     new = list_pkgs()
     ret = salt.utils.data.compare_dicts(old, new)
 
-    if out['retcode'] != 0:
+    if out["retcode"] != 0:
         raise CommandExecutionError(
-            'Error occurred removing package(s)',
+            "Error occurred removing package(s)",
             info={
-                'changes': ret,
-                'retcode': ips_pkg_return_values[out['retcode']],
-                'errors': [out['stderr']]
-            }
+                "changes": ret,
+                "retcode": ips_pkg_return_values[out["retcode"]],
+                "errors": [out["stderr"]],
+            },
         )
 
     return ret
 
 
 def purge(name, **kwargs):
-    '''
+    """
     Remove specified package. Accepts full or partial FMRI.
 
     Returns a list containing the removed packages.
@@ -656,5 +662,5 @@ def purge(name, **kwargs):
     .. code-block:: bash
 
         salt '*' pkg.purge <package name>
-    '''
+    """
     return remove(name, **kwargs)
