@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-r'''
+r"""
 Renderer that will decrypt GPG ciphers
 
 Any key in the SLS file can be a GPG cipher, and this renderer will decrypt it
@@ -14,6 +13,20 @@ developers can add new secrets quickly and easily.
 This renderer requires the gpg_ binary. No python libraries are required as of
 the 2015.8.0 release.
 
+.. _gpg-homedir:
+
+GPG Homedir
+-----------
+
+When running gpg commands, it is important to run commands as the user that owns
+the keys directory. If salt-master runs as user salt, then ``su salt`` before
+running any gpg commands.
+
+To avoid compatibility and upgrade problems and to provide a standardized location
+for keys, salt uses ``/etc/salt/gpgkeys``. In order to make the gpg command use
+this directory, use ``gpg --homedir /etc/salt/gpgkeys`` with gpg commands or set
+the homedir for that user using ``echo 'homedir /etc/salt/gpgkeys' >> ~/.gnupg``.
+
 .. _gpg: https://gnupg.org
 
 Setup
@@ -37,6 +50,54 @@ your application. Be sure to back up the ``gpgkeys`` directory someplace safe!
     increasing the system entropy. On virtualised Linux systems, this can often
     be achieved by installing the ``rng-tools`` package.
 
+Import keys to a master
+***********************
+
+If the keys already exist and need to be imported to the salt master, run the
+following to import them.
+
+.. code-block:: bash
+
+    gpg --homedir /etc/salt/gpgkeys --import /path/to/private.key
+    gpg --homedir /etc/salt/gpgkeys --import /path/to/pubkey.gpg
+
+Note: The default `GPG Homedir <gpg-homedir>` is ``~/.gnupg`` and needs to be
+set using ``--homedir``.
+
+Adjust trust level of imported keys
+***********************************
+
+In some cases, importing existing keys may not be enough and the trust level of
+the key needs to be adjusted. This can be done by editing the key. The ``key_id``
+and the actual trust level of the key can be seen by listing the already imported
+keys.
+
+.. code-block:: bash
+
+    gpg --homedir /etc/salt/gpgkeys --list-keys
+    gpg --homedir /etc/salt/gpgkeys --list-secret-keys
+
+If the trust-level is not ``ultimate`` it needs to be changed by running
+
+.. code-block:: bash
+
+    gpg --homedir /etc/salt/gpgkeys --edit-key <key_id>
+
+This will open an interactive shell for the management of the GPG encryption key.
+Type ``trust`` to be able to set the trust level for the key and then select ``5
+(I trust ultimately)``. Then quit the shell by typing ``save``.
+
+Different GPG Location
+**********************
+
+In some cases, it's preferable to have gpg keys stored on removable media or
+other non-standard locations. This can be done using the ``gpg_keydir`` option
+on the salt master. This will also require using a different path to ``--homedir``,
+as mentioned in the `GPG Homedir <gpg-homedir>` section.
+
+.. code-block:: bash
+
+    gpg_keydir: <path/to/homedir>
 
 Export the Public Key
 ---------------------
@@ -206,92 +267,136 @@ pillar data like so:
 .. code-block:: bash
 
     salt myminion state.sls secretstuff pillar_enc=gpg pillar="$ciphertext"
-'''
 
-# Import python libs
-from __future__ import absolute_import, print_function, unicode_literals
+Configuration
+*************
+
+The default behaviour of this renderer is to log a warning if a block could not
+be decrypted; in other words, it just returns the ciphertext rather than the
+encrypted secret.
+
+This behaviour can be changed via the `gpg_decrypt_must_succeed` configuration
+option.  If set to `True`, any gpg block that cannot be decrypted raises a
+`SaltRenderError` exception, which registers an error in ``_errors`` during
+rendering.
+
+In the Chlorine release, the default behavior will be reversed and an error
+message will be added to ``_errors`` by default.
+"""
+
+
+import logging
 import os
 import re
-import logging
-from subprocess import Popen, PIPE
+from subprocess import PIPE, Popen
 
-# Import salt libs
+import salt.syspaths
+import salt.utils.cache
 import salt.utils.path
 import salt.utils.stringio
 import salt.utils.stringutils
-import salt.syspaths
+import salt.utils.versions
 from salt.exceptions import SaltRenderError
 
-# Import 3rd-party libs
-from salt.ext import six
-
 log = logging.getLogger(__name__)
 
 GPG_CIPHERTEXT = re.compile(
     salt.utils.stringutils.to_bytes(
-        r'-----BEGIN PGP MESSAGE-----.*?-----END PGP MESSAGE-----'
+        r"-----BEGIN PGP MESSAGE-----.*?-----END PGP MESSAGE-----"
     ),
     re.DOTALL,
 )
+GPG_CACHE = None
 
 
 def _get_gpg_exec():
-    '''
+    """
     return the GPG executable or raise an error
-    '''
-    gpg_exec = salt.utils.path.which('gpg')
+    """
+    gpg_exec = salt.utils.path.which("gpg")
     if gpg_exec:
         return gpg_exec
     else:
-        raise SaltRenderError('GPG unavailable')
+        raise SaltRenderError("GPG unavailable")
 
 
 def _get_key_dir():
-    '''
+    """
     return the location of the GPG key directory
-    '''
+    """
     gpg_keydir = None
-    if 'config.get' in __salt__:
-        gpg_keydir = __salt__['config.get']('gpg_keydir')
+    if "config.get" in __salt__:
+        gpg_keydir = __salt__["config.get"]("gpg_keydir")
 
     if not gpg_keydir:
         gpg_keydir = __opts__.get(
-            'gpg_keydir',
+            "gpg_keydir",
             os.path.join(
-                __opts__.get(
-                    'config_dir',
-                    os.path.dirname(__opts__['conf_file']),
-                ),
-                'gpgkeys'
-            ))
+                __opts__.get("config_dir", os.path.dirname(__opts__["conf_file"])),
+                "gpgkeys",
+            ),
+        )
 
     return gpg_keydir
 
 
+def _get_cache():
+    global GPG_CACHE
+    if not GPG_CACHE:
+        cachedir = __opts__.get("cachedir")
+        GPG_CACHE = salt.utils.cache.CacheFactory.factory(
+            __opts__.get("gpg_cache_backend"),
+            __opts__.get("gpg_cache_ttl"),
+            minion_cache_path=os.path.join(cachedir, "gpg_cache"),
+        )
+    return GPG_CACHE
+
+
 def _decrypt_ciphertext(cipher):
-    '''
+    """
     Given a block of ciphertext as a string, and a gpg object, try to decrypt
     the cipher and return the decrypted string. If the cipher cannot be
     decrypted, log the error, and return the ciphertext back out.
-    '''
+    """
     try:
-        cipher = salt.utils.stringutils.to_unicode(cipher).replace(r'\n', '\n')
+        cipher = salt.utils.stringutils.to_unicode(cipher).replace(r"\n", "\n")
     except UnicodeDecodeError:
         # ciphertext is binary
         pass
     cipher = salt.utils.stringutils.to_bytes(cipher)
-    cmd = [_get_gpg_exec(), '--homedir', _get_key_dir(), '--status-fd', '2',
-           '--no-tty', '-d']
+    if __opts__.get("gpg_cache"):
+        cache = _get_cache()
+        if cipher in cache:
+            return cache[cipher]
+    cmd = [
+        _get_gpg_exec(),
+        "--homedir",
+        _get_key_dir(),
+        "--status-fd",
+        "2",
+        "--no-tty",
+        "-d",
+    ]
     proc = Popen(cmd, stdin=PIPE, stdout=PIPE, stderr=PIPE, shell=False)
     decrypted_data, decrypt_error = proc.communicate(input=cipher)
     if not decrypted_data:
-        log.warning(
-            'Could not decrypt cipher %r, received: %r',
-            cipher,
-            decrypt_error
-        )
+        log.warning("Could not decrypt cipher %r, received: %r", cipher, decrypt_error)
+        if __opts__["gpg_decrypt_must_succeed"]:
+            raise SaltRenderError(
+                "Could not decrypt cipher {!r}, received: {!r}".format(
+                    cipher,
+                    decrypt_error,
+                )
+            )
+        else:
+            salt.utils.versions.warn_until(
+                "Chlorine",
+                "After the Chlorine release of Salt, gpg_decrypt_must_succeed will default to True.",
+            )
         return cipher
     else:
+        if __opts__.get("gpg_cache"):
+            cache[cipher] = decrypted_data
         return decrypted_data
 
 
@@ -299,7 +404,7 @@ def _decrypt_ciphertexts(cipher, translate_newlines=False, encoding=None):
     to_bytes = salt.utils.stringutils.to_bytes
     cipher = to_bytes(cipher)
     if translate_newlines:
-        cipher = cipher.replace(to_bytes(r'\n'), to_bytes('\n'))
+        cipher = cipher.replace(to_bytes(r"\n"), to_bytes("\n"))
 
     def replace(match):
         result = to_bytes(_decrypt_ciphertext(match.group()))
@@ -309,7 +414,7 @@ def _decrypt_ciphertexts(cipher, translate_newlines=False, encoding=None):
     if num > 0:
         # Remove trailing newlines. Without if crypted value initially specified as a YAML multiline
         # it will conain unexpected trailing newline.
-        ret = ret.rstrip(b'\n')
+        ret = ret.rstrip(b"\n")
     else:
         ret = cipher
 
@@ -322,37 +427,41 @@ def _decrypt_ciphertexts(cipher, translate_newlines=False, encoding=None):
 
 
 def _decrypt_object(obj, translate_newlines=False, encoding=None):
-    '''
-    Recursively try to decrypt any object. If the object is a six.string_types
-    (string or unicode), and it contains a valid GPG header, decrypt it,
+    """
+    Recursively try to decrypt any object. If the object is a string
+    or bytes and it contains a valid GPG header, decrypt it,
     otherwise keep going until a string is found.
-    '''
+    """
     if salt.utils.stringio.is_readable(obj):
         return _decrypt_object(obj.getvalue(), translate_newlines)
-    if isinstance(obj, six.string_types):
-        return _decrypt_ciphertexts(obj, translate_newlines=translate_newlines, encoding=encoding)
+    if isinstance(obj, (str, bytes)):
+        return _decrypt_ciphertexts(
+            obj, translate_newlines=translate_newlines, encoding=encoding
+        )
     elif isinstance(obj, dict):
-        for key, value in six.iteritems(obj):
-            obj[key] = _decrypt_object(value,
-                                       translate_newlines=translate_newlines)
+        for key, value in obj.items():
+            obj[key] = _decrypt_object(value, translate_newlines=translate_newlines)
         return obj
     elif isinstance(obj, list):
         for key, value in enumerate(obj):
-            obj[key] = _decrypt_object(value,
-                                       translate_newlines=translate_newlines)
+            obj[key] = _decrypt_object(value, translate_newlines=translate_newlines)
         return obj
     else:
         return obj
 
 
-def render(gpg_data, saltenv='base', sls='', argline='', **kwargs):
-    '''
+def render(gpg_data, saltenv="base", sls="", argline="", **kwargs):
+    """
     Create a gpg object given a gpg_keydir, and then use it to try to decrypt
     the data to be rendered.
-    '''
+    """
     if not _get_gpg_exec():
-        raise SaltRenderError('GPG unavailable')
-    log.debug('Reading GPG keys from: %s', _get_key_dir())
+        raise SaltRenderError("GPG unavailable")
+    log.debug("Reading GPG keys from: %s", _get_key_dir())
 
-    translate_newlines = kwargs.get('translate_newlines', False)
-    return _decrypt_object(gpg_data, translate_newlines=translate_newlines, encoding=kwargs.get('encoding', None))
+    translate_newlines = kwargs.get("translate_newlines", False)
+    return _decrypt_object(
+        gpg_data,
+        translate_newlines=translate_newlines,
+        encoding=kwargs.get("encoding", None),
+    )
