@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-'''
+"""
 Management of OpenStack Neutron Subnets
 =========================================
 
@@ -45,22 +44,23 @@ Example States
         - name: v6subnet1
         - network_name_or_id: network1
         - ip_version: 6
-'''
+"""
 
-from __future__ import absolute_import, print_function, unicode_literals
 
-__virtualname__ = 'neutron_subnet'
+__virtualname__ = "neutron_subnet"
 
 
 def __virtual__():
-    if 'neutronng.list_subnets' in __salt__:
+    if "neutronng.list_subnets" in __salt__:
         return __virtualname__
-    return (False, 'The neutronng execution module failed to load:\
-                    shade python module is not available')
+    return (
+        False,
+        "The neutronng execution module failed to load: shade python module is not available",
+    )
 
 
 def present(name, auth=None, **kwargs):
-    '''
+    """
     Ensure a subnet exists and is up-to-date
 
     name
@@ -90,81 +90,75 @@ def present(name, auth=None, **kwargs):
     ipv6_address_mode
         IPv6 address mode.
         Valid values are: ‘dhcpv6-stateful’, ‘dhcpv6-stateless’, or ‘slaac’.
-    '''
-    ret = {'name': name,
-           'changes': {},
-           'result': True,
-           'comment': ''}
+    """
+    ret = {"name": name, "changes": {}, "result": True, "comment": ""}
 
-    kwargs = __utils__['args.clean_kwargs'](**kwargs)
+    kwargs = __utils__["args.clean_kwargs"](**kwargs)
 
-    __salt__['neutronng.setup_clouds'](auth)
+    __salt__["neutronng.setup_clouds"](auth)
 
-    kwargs['subnet_name'] = name
-    subnet = __salt__['neutronng.subnet_get'](name=name)
+    kwargs["subnet_name"] = name
+    subnet = __salt__["neutronng.subnet_get"](name=name)
 
     if subnet is None:
-        if __opts__['test']:
-            ret['result'] = None
-            ret['changes'] = kwargs
-            ret['comment'] = 'Subnet will be created.'
+        if __opts__["test"]:
+            ret["result"] = None
+            ret["changes"] = kwargs
+            ret["comment"] = "Subnet will be created."
             return ret
 
-        new_subnet = __salt__['neutronng.subnet_create'](**kwargs)
-        ret['changes'] = new_subnet
-        ret['comment'] = 'Created subnet'
+        new_subnet = __salt__["neutronng.subnet_create"](**kwargs)
+        ret["changes"] = new_subnet
+        ret["comment"] = "Created subnet"
         return ret
 
-    changes = __salt__['neutronng.compare_changes'](subnet, **kwargs)
+    changes = __salt__["neutronng.compare_changes"](subnet, **kwargs)
     if changes:
-        if __opts__['test'] is True:
-            ret['result'] = None
-            ret['changes'] = changes
-            ret['comment'] = 'Project will be updated.'
+        if __opts__["test"] is True:
+            ret["result"] = None
+            ret["changes"] = changes
+            ret["comment"] = "Project will be updated."
             return ret
 
         # update_subnet does not support changing cidr,
         # so we have to delete and recreate the subnet in this case.
-        if 'cidr' in changes or 'tenant_id' in changes:
-            __salt__['neutronng.subnet_delete'](name=name)
-            new_subnet = __salt__['neutronng.subnet_create'](**kwargs)
-            ret['changes'] = new_subnet
-            ret['comment'] = 'Deleted and recreated subnet'
+        if "cidr" in changes or "tenant_id" in changes:
+            __salt__["neutronng.subnet_delete"](name=name)
+            new_subnet = __salt__["neutronng.subnet_create"](**kwargs)
+            ret["changes"] = new_subnet
+            ret["comment"] = "Deleted and recreated subnet"
             return ret
 
-        __salt__['neutronng.subnet_update'](**kwargs)
-        ret['changes'].update(changes)
-        ret['comment'] = 'Updated subnet'
+        __salt__["neutronng.subnet_update"](**kwargs)
+        ret["changes"].update(changes)
+        ret["comment"] = "Updated subnet"
 
     return ret
 
 
 def absent(name, auth=None):
-    '''
+    """
     Ensure a subnet does not exists
 
     name
         Name of the subnet
 
-    '''
-    ret = {'name': name,
-           'changes': {},
-           'result': True,
-           'comment': ''}
+    """
+    ret = {"name": name, "changes": {}, "result": True, "comment": ""}
 
-    __salt__['neutronng.setup_clouds'](auth)
+    __salt__["neutronng.setup_clouds"](auth)
 
-    subnet = __salt__['neutronng.subnet_get'](name=name)
+    subnet = __salt__["neutronng.subnet_get"](name=name)
 
     if subnet:
-        if __opts__['test'] is True:
-            ret['result'] = None
-            ret['changes'] = {'id': subnet.id}
-            ret['comment'] = 'Project will be deleted.'
+        if __opts__["test"] is True:
+            ret["result"] = None
+            ret["changes"] = {"id": subnet.id}
+            ret["comment"] = "Project will be deleted."
             return ret
 
-        __salt__['neutronng.subnet_delete'](name=subnet)
-        ret['changes']['id'] = name
-        ret['comment'] = 'Deleted subnet'
+        __salt__["neutronng.subnet_delete"](name=subnet)
+        ret["changes"]["id"] = name
+        ret["comment"] = "Deleted subnet"
 
     return ret
